stalker.core.models.SimpleEntity
================================

.. inheritance-diagram::
     stalker.core.models.SimpleEntity
     :parts: 1

.. currentmodule:: stalker.core.models

.. autoclass:: SimpleEntity
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SimpleEntity.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~SimpleEntity.code
      ~SimpleEntity.created_by
      ~SimpleEntity.date_created
      ~SimpleEntity.date_updated
      ~SimpleEntity.description
      ~SimpleEntity.name
      ~SimpleEntity.nice_name
      ~SimpleEntity.type
      ~SimpleEntity.updated_by
   
   